<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">

<xsl:include href='gjsForm.xsl'/>

<xsl:template match="Form">
  <xsl:apply-templates select="changeRequestType"/>
</xsl:template>

<xsl:template match="changeRequestType">
  <xsl:variable name='readonly'>
    <xsl:choose>
      <xsl:when test='../@method="view"'>
        <xsl:text>1</xsl:text>
      </xsl:when>          
      <xsl:otherwise>
        <xsl:text>0</xsl:text>
      </xsl:otherwise>          
    </xsl:choose>
  </xsl:variable>

<gjs:form
 title='Change Request Type'
 width='510'
 jsFile='vc421.js'
 onload='frmMain.changeRequestType.focus();'
 save='{/Form/@save}'
 close='{/Form/@close}'
 delete='{/Form/@delete}'
 print='{/Form/@print}'
 help='{/Form/@help}'
 ok='{/Form/@ok}'
 cancel='{/Form/@cancel}'>


  <gjs:information>
    Change request types define a profile for change requests.&nbsp; Each type 
    can have its own caption, number range, status codes and audit trail level.&nbsp; For
    example, one series of change requests could be used for recording software bug fixes;
    another to represent project codes; another for website
    proof-reading corrections.
    <xsl:if test='$readonly=1'>
      NOTE: Change request types cannot be added or amended on your edition of Deltanji.
    </xsl:if>
  </gjs:information>

<div id='divChangeRequestType' class='visible' style='min-height: 240px'>
  <gjs:frame>
  <!-- Set up frame column widths -->
  <gjs:columnWidths>
    <gjs:column width='100'/>
    <gjs:column width='240'/>
    <gjs:column width='60'/>
    <gjs:column width='20'/>
  </gjs:columnWidths>

  <gjs:fields>
    <tr>
      <gjs:input
       id='changeRequestType'
       accesskey='T'
       size='16'
       maxlength='16'
       value='{@changeRequestType}'
       onchange='Form.fnChanged()'
       readonly='{$readonly}'
       row='0'>
       <label><u>T</u>ype</label>
       <hint>Enter a name that identifies this change request type</hint>
      </gjs:input>
      
      <gjs:checkbox
       id='withdrawn'
       accesskey='W'
       checked='{@withdrawn}'
       value='1'
       title='Check to prevent this type being used'
       readonly='{$readonly}'
       row='0'>
        <label><u>W</u>ithdrawn</label>
      </gjs:checkbox>

    </tr>

    <gjs:input
     id='description'
     accesskey='E'
     size='29'
     maxlength='40'
     value='{@description}'
     onchange='Form.fnChanged()'
     readonly='{$readonly}'>
     <label>D<u>e</u>scription</label>
     <hint>Enter a description of this change request type</hint>
    </gjs:input>

    <gjs:input
     id='caption'
     accesskey='N'
     size='16'
     maxlength='18'
     value='{@caption}'
     onchange='Form.fnChanged()'
     readonly='{$readonly}'>
     <label>Captio<u>n</u></label>
     <hint>Enter a caption to be used when displaying change requests of this type</hint>
    </gjs:input>

    <gjs:input
     id='prefix'
     accesskey='F'
     size='29'
     maxlength='29'
     value='{@prefix}'
     onchange='Form.fnChanged()'
     readonly='{$readonly}'>
     <label>Pre<u>f</u>ix</label>
     <hint>Enter a prefix for automatically generated change request codes of this type</hint>
    </gjs:input>

    <gjs:input
     id='lastUsedSuffix'
     accesskey='X'
     size='29'
     maxlength='29'
     value='{@lastUsedSuffix}'
     onchange='Form.fnChanged()'
     readonly='{$readonly}'>
      <label>Last used suffi<u>x</u></label>
      <hint><xsl:text>Enter a template for the sequence number to be used for automatically generated change request codes of this type.

For example, 1000 for a 4 digit serial number starting from 1000, or 0+ for a variable length sequence number starting from 1.</xsl:text></hint>
    </gjs:input>
    
    <gjs:list1
     id='allowedMemberTypes'
     accesskey='M'
     value='{@allowedMemberTypes}'
     onchange='Form.fnChanged()'
     >
	    <xsl:if test='$readonly="1"'>
	      <xsl:attribute name='disabled'/>  
	    </xsl:if>
      <label><u>M</u>embers</label>
      <hint>What kind of items can be added to change requests of this type</hint>
      <item>
			 <label>Objects</label>
			 <value>1</value>
			</item>
      <item>
			 <label>Change requests</label>
			 <value>2</value>
			</item>
      <item>
			 <label>Objects and change requests</label>
			 <value>3</value>
			</item>
    </gjs:list1>

    <tr>
      <td height='16'></td>
    </tr>

    <tr>
      <td></td>
      <td colspan='3'>
        <table class='formLayoutTable'>
              <tr>
                <gjs:column width='25'/>
                <gjs:column width='100'/>
                <gjs:column width='180'/>
              </tr>
              <tr>
                <td height='20'></td>
                <gjs:caption><label>Stat<u>u</u>s</label></gjs:caption>
                <!-- Tied location being hidden pending removal or reuse
                <gjs:caption><label>Tied <u>l</u>ocation</label></gjs:caption>
                -->
              </tr>            
        </table>
      </td>
    </tr>
    <tr>
      <gjs:caption for='divStatii' accesskey='U'>
        <label>
          <div align='right'>
          <button type='button' onclick='fnMoveUp()'>
						<xsl:if test='$readonly="1"'>
							<xsl:attribute name='disabled'/>
						</xsl:if>
            &nbsp;<img src='gjsSortDescending.gif'/>&nbsp;
          </button>&nbsp;&nbsp;
          <br/>
          <button type='button' onclick='fnMoveDown()'>
						<xsl:if test='$readonly="1"'>
							<xsl:attribute name='disabled'/>
						</xsl:if>
            &nbsp;<img src='gjsSortAscending.gif'/>&nbsp;
          </button>&nbsp;&nbsp;
          </div>
        </label>
      </gjs:caption>
      <td colspan='3'>
        <div class='gridTableOuter' style='height: 98px;'>
          <table class='formLayoutTable'>
          </table>
          <div class='gridTableInner' style='height: 98px;' id='divStatii'>
            <table class='formLayoutTable'>
              <tr>
                <gjs:column width='25'/>
                <gjs:column width='100'/>
                <gjs:column width='180'/>
              </tr>

              <xsl:call-template name='status'>
                <xsl:with-param name='style' select='"display: none;"'/>
                <xsl:with-param name='lastRow' select='"1"'/> <!-- sic -->
                <xsl:with-param name='readonly' select='"0"'/>
             </xsl:call-template>
              <xsl:apply-templates select='/Form/changeRequestType/changeRequestStatii/changeRequestStatus' mode='grid'>
                <xsl:sort select='@statusSequence' data-type='number'/>
                <xsl:with-param name='style' select='""'/>
                <xsl:with-param name='lastRow' select='"0"'/>
                <xsl:with-param name='readonly' select='$readonly'/>
              </xsl:apply-templates>
      				<xsl:if test='$readonly="0"'>
                <xsl:call-template name='status'>
                  <xsl:with-param name='style' select='""'/>
                  <xsl:with-param name='lastRow' select='"1"'/>
                  <xsl:with-param name='readonly' select='"0"'/>
                </xsl:call-template>
          		</xsl:if>
            </table>
          </div>
        </div>
      </td>
    </tr>

    <tr>
      <td height='16'></td>
    </tr>

    <gjs:list1
     id='initialStatus'
     accesskey='I'
     width='100'
     value='{@initialStatus}'
     onchange='Form.fnChanged()'>
		  <xsl:if test='$readonly="1"'>
		    <xsl:attribute name='disabled'/>  
		  </xsl:if>
      <label><u>I</u>nitial status</label>
      <hint>If statuses are being used, optionally enter the initial status of a new change request of this type</hint>
      <item>
        <label></label>
        <value></value>
      </item>
      <xsl:apply-templates select="/Form/changeRequestType/changeRequestStatii/changeRequestStatus" mode='list1'>
        <xsl:sort select='@statusSequence'/>
      </xsl:apply-templates>
    </gjs:list1>

     <tr>
      <td height='16'></td>
    </tr>

    <tr>
      <td>Audit trail categories:</td>
      <td colspan='3'>
      
      <div class='gridTableOuter'>
        <table class='formLayoutTable'>
        </table>
        <div class='gridTableInner' id='divStatii'>
          <table class='formLayoutTable'>
            <tr>
              <gjs:column width='110'/>
              <gjs:column width='180'/>
            </tr>
           
              <tr>
                <td height='8'></td>
              </tr>
              
              <gjs:list1
                id='changeRequestEventCategory'
                accesskey='H'
                width='172'
                value='{@changeRequestEventCategory}'
                onchange='Form.fnChanged()'>
          		  <xsl:if test='$readonly="1"'>
          		    <xsl:attribute name='disabled'/>  
          		  </xsl:if>
                <label>&nbsp;&nbsp;&nbsp;&nbsp;C<u>h</u>ange requests</label>
                <hint><xsl:text>Pick the audit trail category to use for events relating to change requests of this type.</xsl:text></hint>
                <xsl:apply-templates select='/Form/categories/category' mode='list1'>
                  <xsl:sort select='@name'/>         
                </xsl:apply-templates>
              </gjs:list1>

              <gjs:list1
                id='objectEventCategory'
                accesskey='O'
                width='172'
                value='{@objectEventCategory}'
                onchange='Form.fnChanged()'>
          		  <xsl:if test='$readonly="1"'>
          		    <xsl:attribute name='disabled'/>  
          		  </xsl:if>
                <label>&nbsp;&nbsp;&nbsp;&nbsp;<u>O</u>bjects</label>
                <hint><xsl:text>Pick the audit trail category to use for events relating to object additions and removals to change requests of this type.</xsl:text></hint>
                <xsl:apply-templates select='/Form/categories/category' mode='list1'>
                  <xsl:sort select='@name'/>         
                </xsl:apply-templates>
              </gjs:list1>

	      <gjs:list1
                id='transferEventCategory'
                accesskey='R'
                width='172'
                value='{@transferEventCategory}'
                onchange='Form.fnChanged()'>
          		  <xsl:if test='$readonly="1"'>
          		    <xsl:attribute name='disabled'/>  
          		  </xsl:if>
                <label>&nbsp;&nbsp;&nbsp;&nbsp;T<u>r</u>ansfers</label>
                <hint><xsl:text>Pick the audit trail category to use for transfers by change request.</xsl:text></hint>
                <xsl:apply-templates select='/Form/categories/category' mode='list1'>
                  <xsl:sort select='@name'/>         
                </xsl:apply-templates>
              </gjs:list1>

              <tr>
                <td height='8'></td>
              </tr>

            </table>
          </div>
        </div>
      </td>    
    </tr>
  </gjs:fields>

  <gjs:inputHidden id='revision' value='{@revision}'/>
  <gjs:inputHidden id='oldChangeRequestType' value='{@changeRequestType}'/>

  </gjs:frame>
</div>
</gjs:form>
</xsl:template>


<xsl:template match='/Form/changeRequestType/changeRequestStatii/changeRequestStatus' name='status' mode="grid">
  <xsl:param name='style'/>
  <xsl:param name='readonly'/>
  <xsl:param name='lastRow'/>
  <tr 
   style='{$style}'
   gjsLastRow='{$lastRow}'>
    <td>
      <img src='vcm_record.gif'
       height='16'
       width='25'>
				<xsl:if test='$readonly="0"'>
					<xsl:attribute name='title'>Click to select row prior to reordering</xsl:attribute>
					<xsl:attribute name='onclick'>fnItemSelect(this.parentNode.parentNode)</xsl:attribute>
    		</xsl:if>
      </img>
    </td>
    <td>
      <input 
       type='text' 
       size='15'
       maxlength='15' 
       id='status' 
       name='status' 
       value='{@status}'
       readonly='{$readonly}'
			 title='Optionally define statuses that can be assigned to change requests of this type' 
       class='inputDisabled'>
				<xsl:if test='$readonly="0"'>
					<xsl:attribute name='class'>input</xsl:attribute>
					<xsl:attribute name='onkeypress'>fnRowChanged(this)</xsl:attribute>
					<xsl:attribute name='onchange'>fnUpdateInitialStatus();</xsl:attribute>
    		</xsl:if>
      </input>
    </td>
    <td>
      <input 
       type='text' 
       size='20'
       id='tiedLocation'
       name='tiedLocation'
       value='{@tiedLocation}'
       readonly='{$readonly}'
       tabindex='-1'
       title='The feature using this field has been deprecated and will be removed in a future version'
       />
    </td>
  </tr>
</xsl:template>

<!-- Location list boxes -->
<xsl:template match='location' mode="list1">
<item>
  <label><xsl:value-of select="@location" /></label>
  <value><xsl:value-of select="@location" /></value>
</item>
</xsl:template>

<!-- Change Request Type status list box -->
<xsl:template match='changeRequestStatii/changeRequestStatus' mode="list1">
<item>
  <label><xsl:value-of select="@status" /></label>
  <value><xsl:value-of select="@status" /></value>
</item>
</xsl:template>


<!-- category list boxes -->
<xsl:template match='category' mode="list1">
<item>
  <label><xsl:value-of select="@name" /></label>
  <value><xsl:value-of select="@category" /></value>
</item>
</xsl:template>


</xsl:stylesheet>
