<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- Copyright 2004 George James Software Limited -->

<!-- This stylesheet creates namespaces and for each VC/m M type physical location.
     It takes as input an xml file conforming to the schema defined in vcmConfiguration.xsd.
     Typically this is the pass 2 output from the vcmConfiguration compilation process.
     It outputs an xml file conforming to the schema defined in cacheCpf.xsd.  This is
     subsequently used to create a cache.cpf file.
     -->

<xsl:output method='xml' indent='yes'/>


<xsl:template match="VCm">

<xsl:variable name='parameters' select='document("vcmCpfParameters.xml")/parameters'/>
<cpf
 lastUsedDatabaseNumber="{$parameters/lastUsedDatabaseNumber/@value}"
 lastUsedNamespaceNumber="{$parameters/lastUsedNamespaceNumber/@value}"
 >

  <databases>
    <xsl:apply-templates select='physicalLocation[@storageFormat="M"]' mode='databases'>
      <xsl:with-param name='rootForDatabases' select='$parameters/rootForDatabases/@value'/>
      <xsl:with-param name='vcmDatabase' select='$parameters/vcmDatabase/@value'/>
    </xsl:apply-templates>
  </databases>

  <namespaces>
    <xsl:apply-templates select='physicalLocation[@storageFormat="M"]' mode='namespaces'>
      <xsl:with-param name='rootForDatabases' select='$parameters/rootForDatabases/@value'/>
      <xsl:with-param name='vcmDatabase' select='$parameters/vcmDatabase/@value'/>
    </xsl:apply-templates>
  </namespaces>
</cpf>

</xsl:template>


<xsl:template match="physicalLocation" mode='databases'>
  <xsl:param name='rootForDatabases'/>
  <xsl:param name='vcmDatabase'/>
  <database name='{@physicalAddress}' directory='{$rootForDatabases}{@physicalAddress}'/>
</xsl:template>

<xsl:template match="physicalLocation" mode='namespaces'>
  <xsl:param name='rootForDatabases'/>
  <xsl:param name='vcmDatabase'/>
  <namespace name='{@physicalAddress}'>
    <globalMap mask='%vc*' database='{$vcmDatabase}'/>
    <routineMap mask='%vc*' database='{$vcmDatabase}'/>
    <routineMap mask='%SerenjC' database='{$vcmDatabase}'/>
  </namespace>

</xsl:template>


</xsl:stylesheet>
