<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">

<xsl:include href='gjsForm.xsl'/>

<xsl:template match="Form">
  <xsl:apply-templates select="locationClass"/>
</xsl:template>

<xsl:template match="locationClass">
  <xsl:variable name='readonly'>
    <xsl:choose>
      <xsl:when test='../@method="view"'>
        <xsl:text>1</xsl:text>
      </xsl:when>          
      <xsl:otherwise>
        <xsl:text>0</xsl:text>
      </xsl:otherwise>          
    </xsl:choose>
  </xsl:variable>

<gjs:form
 title='Location List'
 width='450'
 jsFile='vc291.js'
 onload='frmMain.locationClass.focus();'
 save='{/Form/@save}'
 close='{/Form/@close}'
 delete='{/Form/@delete}'
 print='{/Form/@print}'
 help='{/Form/@help}'
 ok='{/Form/@ok}'
 cancel='{/Form/@cancel}'>

  <gjs:information>
    A location list defines an ordered set of locations that can be referenced by a single name.&nbsp; 
    Location lists can be used in various places within Deltanji as a shortcut
    way of referring to multiple locations.&nbsp;
    <xsl:choose>
      <xsl:when test='@genByKey!=""'>
        This record cannot be amended because it was derived from the <xsl:value-of select='@genByKey'/> template.
      </xsl:when>
        <xsl:when test='$readonly=1'>
          NOTE: Use of this feature is limited on your edition of Deltanji.
        </xsl:when>
      <xsl:otherwise>
        Templates can be defined by using {variable} notation in the key field.
      </xsl:otherwise>
    </xsl:choose>
  </gjs:information>

<div id='divLclass' class='visible' style='min-height: 240px;'>
  <gjs:frame>
  <!-- Set up frame column widths -->
  <gjs:columnWidths>
    <gjs:column width='100'/>
    <gjs:column width='340'/>
  </gjs:columnWidths>

  <gjs:fields>

    <gjs:input
     id='locationClass'
     accesskey='L'
     size='30'
     maxlength='30'
     value='{@locationClass}'
     onchange='Form.fnChanged()'
     readonly='{$readonly}'>
     <label><u>L</u>ist</label>
     <hint>Name that identifies an ordered set of locations</hint>
    </gjs:input>

    <gjs:input
     id='description'
     accesskey='E'
     size='40'
     maxlength='40'
     value='{@description}'
     onchange='Form.fnChanged()'
     readonly='{$readonly}'>
     <label>D<u>e</u>scription</label>
     <hint>Description of this location list</hint>
    </gjs:input>

    <tr valign="top">
      <gjs:caption for='inClass' accesskey='O'>
        <label>
          L<u>o</u>cations
          <xsl:if test='$readonly!="1"'>
            <div align='right'>
            <button
              type='button'
              title='Move the highlighted row up the list'
					    onclick='fnMoveUp(); Form.fnChanged()'>
              &nbsp;<img src='gjsSortDescending.gif'/>&nbsp;
            </button>&nbsp;&nbsp;
            <br/>
            <button
              type='button'
              id='btnSort'
              accesskey='S'
              value='AZ'
              title='Sort the checked rows in the indicated order and group them at the top of the list. Unchecked rows will always be re-sorted A-Z.'
				  	  onclick='fnSort(); Form.fnChanged()'>
              <u>S</u>ort A-Z
            </button>&nbsp;&nbsp;
            <br/>
            <button
              type='button'
              title='Move the highlighted row down the list'
				  	  onclick='fnMoveDown(); Form.fnChanged()'>
              &nbsp;<img src='gjsSortAscending.gif'/>&nbsp;
            </button>&nbsp;&nbsp;
            <br/>
            </div>
          </xsl:if>
        </label>
      </gjs:caption>
      <td>
        <div class='gridTableOuter' style='min-height: 185px; width: 310px;'>
          <table class='formLayoutTable'>
          </table>
          <div class='gridTableInner' style='height: 185px;' id='divLocations'>
            <table class='formLayoutTable'>
              <tr>
                <gjs:column width='20'/>
                <gjs:column width='183'/>
              </tr>
              <xsl:apply-templates select="/Form/locationClass/locationsInClass/location" mode='grid'>
                <xsl:with-param name='inClass' select='"Y"'/>
                <xsl:with-param name='readonly' select='$readonly'/>
              </xsl:apply-templates>
              <xsl:if test='$readonly!="1"'>
                <xsl:apply-templates select="/Form/locationClass/locationsNotInClass/location" mode='grid'>
                  <xsl:with-param name='inClass' select='"N"'/>
                  <xsl:with-param name='readonly' select='$readonly'/>
                </xsl:apply-templates>
              </xsl:if>
            </table>
          </div>
        </div>
      </td>
    </tr>
    
    <tr>
      <gjs:caption><label>Access rights:</label></gjs:caption>
      <td></td>
    </tr>

    <gjs:input
     id='accessCodes'
     accesskey='V'
     size='40'
     maxlength='1000'
     value='{@accessCodes}'
     onchange='Form.fnChanged()'
     readonly='{$readonly}'>
       <label> - to <u>v</u>iew</label>
       <hint>Comma-separated list of access rights controlling which users can <i>see</i> this location list. If empty then no restriction applies.</hint>
    </gjs:input>

    <gjs:input
     id='modifyAccessCodes'
     accesskey='M'
     size='40'
     maxlength='1000'
     value='{@modifyAccessCodes}'
     onchange='Form.fnChanged()'
     readonly='{$readonly}'>
       <label> - to <u>m</u>odify</label>
       <hint>Comma-separated list of access rights controlling which users can <i>modify</i> the set of locations comprising this location list. If empty then no restriction applies.</hint>
    </gjs:input>

  </gjs:fields>

  <gjs:inputHidden id='revision' value='{@revision}'/>
  <gjs:inputHidden id='oldLocationClass' value='{@locationClass}'/>

  </gjs:frame>
</div>
</gjs:form>
</xsl:template>

<xsl:template match='location' name='lcode' mode="grid">
  <xsl:param name='inClass'/>
  <xsl:param name='readonly'/>
  <tr
   name='rowClass'
   title='Check the box to make this location a member of the location list. A newly-checked item will immediately be promoted to the upper part of the list where all checked items are gathered. Highlight a row and click on the Up or Down button to change its position in the list.'
   class='row'
   onclick='fnItemSelect(this)'>
    <td>
      <input 
       type='checkbox'
       id='inClass'
       name='inClass'
       accesskey='c'
       onclick='Form.fnChanged(); this.style.cursor="wait"; setTimeout(function(){{fnToggleCheckbox(this); this.style.cursor="auto"}}.bind(this), this.checked ? 400 : 0);'
       gjsLcode='{@location}'>
        <xsl:if test='$inClass="Y"'>
          <xsl:attribute name='checked'>checked</xsl:attribute>
        </xsl:if>
        <xsl:if test='$readonly="1"'>
          <xsl:attribute name='disabled'>disabled</xsl:attribute>
          <xsl:attribute name='class'>inputDisabled</xsl:attribute>
        </xsl:if>
      </input>
    </td>
    <td style='padding-left: 5px;'>
      <xsl:value-of select='@location'/>
    </td>
  </tr>
</xsl:template>


</xsl:stylesheet>
